@@ -47,7 +47,7 @@ def cli():
         #     data = yaml.dump(yml_data, f, sort_keys=False, default_flow_style=False)
         #     print(data)
 
-    file_exists = exists(os.getcwd() + '/gitlab-ci.yml')
+    # file_exists = exists(os.getcwd() + '/gitlab-ci.yml')
 
 @main.command()
 @click.option('--flag', type=click.Choice(['flat', 'modular'], case_sensitive=False), default='flat')
@@ -71,71 +71,29 @@ def run(flag):
                         ]
 
     folder_list = []
-    if flag == 'flat':
-        # get all folder name
-        f = drive.ListFile({"q": "mimeType='application/vnd.google-apps.folder' or mimeType='applicationvnd.google-apps.folder' and trashed=false"}).GetList()
-        for folder in f:
-            folder_list.append(folder['title'])
-        for name in flat_folder_list:
+    # get all folder name
+    f = drive.ListFile({
+                           "q": "mimeType='application/vnd.google-apps.folder' or mimeType='applicationvnd.google-apps.folder' and trashed=false"}).GetList()
+    for folder in f:
+        folder_list.append(folder['title'])
+
+    for name in flat_folder_list:
+        # Create folder
+
+        if name not in folder_list:
             # Create folder
-
-            if name not in folder_list:
-                # Create folder
-                folder_metadata = {'title': name, 'mimeType': 'applicationvnd.google-apps.folder'}
-                if name.endswith('.pptx') or name.endswith('.pdf'):
-                    folder = drive.CreateFile(folder_metadata)
-                    folder.Upload()
-                else:
-                    folder = drive.CreateFile({'title': name, 'mimeType': 'application/vnd.google-apps.folder'})
-                    folder.Upload()
-    if flag == 'modular':
-        module_name = ['module_A', 'module_B', 'Test Slide Deck.pptx', 'Test Study Protocol.pdf']
-        module_folder_inside_structure = ['Abstracts',
-                                          'Data Partners',
-                                          'Documentation',
-                                          'Manuscripts',
-                                          'Outputs',
-                                          'Posters',
-                                          'Presentations',
-                                          'References',
-                                          'Reports'
-                                          ]
-        module_name_list = []
-        module_id = []
-        # get all folder name
-        f = drive.ListFile({
-            "q": "mimeType='application/vnd.google-apps.folder' or mimeType='applicationvnd.google-apps.folder'  and trashed=false"}).GetList()
-        for folder in f:
-            module_name_list.append(folder['title'])
-            module_id.append(folder['id'])
-
-        for m_name in module_name:
-            if m_name not in module_name_list:
-                parent_folder = drive.CreateFile({'title': m_name, 'mimeType': 'applicationvnd.google-apps.folder'})
-                if m_name.endswith('.pptx') or m_name.endswith('.pdf'):
-                    folder = drive.CreateFile(parent_folder)
-                    folder.Upload()
-
-                else:
-                    folder = drive.CreateFile({'title': m_name, 'mimeType': 'application/vnd.google-apps.folder'})
-                    folder.Upload()
-
-        for flat_name in module_folder_inside_structure:
-            for module_id in module_id:
-                if flat_name not in module_name_list or module_id not in module_id:
-                    folder_metadata = drive.CreateFile({'title': flat_name, "parents": [{'id': module_id}],
-                                                        'mimeType': 'application/vnd.google-apps.folder'})
-                    folder_metadata.Upload()
+            folder_metadata = {'title': name, 'mimeType': 'applicationvnd.google-apps.folder'}
+            if name.endswith('.pptx') or name.endswith('.pdf'):
+                folder = drive.CreateFile(folder_metadata)
+                folder.Upload()
+            else:
+                folder = drive.CreateFile({'title': name, 'mimeType': 'application/vnd.google-apps.folder'})
+                folder.Upload()
 
     # Get folder info and print to screen
     foldertitle = folder['title']
     folderid = folder['id']
 
-    # Upload file to folder
-    # file = drive.CreateFile({"parents": [{"kind": "drive#fileLink", "id": folderid}]})
-    # file.SetContentFile('data1.xlsx')
-    # file.Upload()
-
     str = "\'" + folderid + "\'" + " in parents and trashed=false"
     file_list_names = []
     file_list = drive.ListFile({'q': str}).GetList()
@@ -250,3 +208,7 @@ def GetBoardFromGitlab():  # for getting repository information
     jsondata = r.json()
     myBoardName = jsondata.get('name')
     return myBoardName
+
+cli()
+run('flat')
+seed()
\ No newline at end of file
